# ml1-10

This package visualizes numeric features from the California Housing dataset using histograms and boxplots, and detects outliers using the IQR method.


ml1-10
This Python package provides 10 utility functions (p1 to p10) for EDA and machine learning workflows.